Crate midenc_dialect_hir

Crate midenc_dialect_hir 

Modules

assertions
This module contains the set of compiler-emitted assertion codes, along with their explanations
transforms

Structs

Assert
AssertBuilder
A specialized builder for Assert, which is used by calling it like a function.
AssertEq
AssertEqBuilder
A specialized builder for AssertEq, which is used by calling it like a function.
Assertz
AssertzBuilder
A specialized builder for Assertz, which is used by calling it like a function.
Bitcast
BitcastBuilder
A specialized builder for Bitcast, which is used by calling it like a function.
Breakpoint
BreakpointBuilder
A specialized builder for Breakpoint, which is used by calling it like a function.
Call
CallBuilder
A specialized builder for Call, which is used by calling it like a function.
Cast
CastBuilder
A specialized builder for Cast, which is used by calling it like a function.
ConstantBytes
A constant operation used to define an array of arbitrary bytes.
ConstantBytesBuilder
A specialized builder for ConstantBytes, which is used by calling it like a function.
ConstantPointer
An operation for expressing constant pointer values.
ConstantPointerBuilder
A specialized builder for ConstantPointer, which is used by calling it like a function.
Exec
ExecBuilder
A specialized builder for Exec, which is used by calling it like a function.
HirDialect
IntToPtr
IntToPtrBuilder
A specialized builder for IntToPtr, which is used by calling it like a function.
Load
Load result from the heap at addr
LoadBuilder
A specialized builder for Load, which is used by calling it like a function.
LoadLocal
LoadLocalBuilder
A specialized builder for LoadLocal, which is used by calling it like a function.
MemCpy
MemCpyBuilder
A specialized builder for MemCpy, which is used by calling it like a function.
MemGrow
MemGrowBuilder
A specialized builder for MemGrow, which is used by calling it like a function.
MemSet
MemSetBuilder
A specialized builder for MemSet, which is used by calling it like a function.
MemSize
MemSizeBuilder
A specialized builder for MemSize, which is used by calling it like a function.
PointerAttr
Represents a constant pointer value
PtrToInt
PtrToIntBuilder
A specialized builder for PtrToInt, which is used by calling it like a function.
Reload
ReloadBuilder
A specialized builder for Reload, which is used by calling it like a function.
Spill
SpillBuilder
A specialized builder for Spill, which is used by calling it like a function.
Store
Store value on the heap at addr
StoreBuilder
A specialized builder for Store, which is used by calling it like a function.
StoreLocal
Store value on in procedure local memory
StoreLocalBuilder
A specialized builder for StoreLocal, which is used by calling it like a function.

Traits

HirOpBuilder